
# Slot: exactly_one_of


holds if only one of the expressions hold

URI: [linkml:exactly_one_of](https://w3id.org/linkml/exactly_one_of)


## Domain and Range

None &#8594;  <sub>0..\*</sub> expression

## Parents

 *  is_a: boolean_slot

## Children

 *  class_expression_exactly_one_of
 *  slot_expression_exactly_one_of
 *  type_expression_exactly_one_of

## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **Exact Mappings:** | | sh:xone |

